
% Use Euler's method to solve for x(t) for constant velocity motion
%   dx/dt = v = const.
%

close all
clc
clear

v    = 10;     % velocity (m/s)
dt   = 0.5;    % time step (s)
tmax = 10;     % maximum time

N = ceil(tmax / dt) + 1;   % number of time steps

% preallocate arrays
t = zeros(1,N);
x = zeros(1,N);

% set initial conditions
t(1) = 0;      % initial time
x(1) = 0;      % initial position

% update new position at time t(n+1) based on old position at time t(n)
for n = 1:N-1
    t(n+1) = t(n) + dt;
    x(n+1) = x(n) + v * dt;
end

% plot position vs. time
plot(t,x,'ro','MarkerFaceColor','r')
xlabel('t (s)')
ylabel('x (m)')

h = 4;                                  % height of plot in inches
w = 6;                                  % width of plot in inches
set(gcf, 'PaperSize', [w h]);           % set size of PDF page
set(gcf, 'PaperPosition', [0 0 w h]);   % put plot in lower-left corner
print ('-dpdf','ode01.pdf');             % save plot as pdf file
