    % air_drag_1D_derivs - Function defining derivatives dx/dt and dv/dt
    %
    % Force on object = gravity + drag force
    %                 = -g  - C_d * v * |v| 
    %
    % Assumes tubulent drag, with drag force = F_d = C_d * v^2
    %   where C_d is the air drag coefficient that must be defined as a
    %   global variable in the calling program.
    %
    % The drag force always opposes the motion (i.e. velocity) of the
    % object, so it may be written as 
    % 
    % Required global variables:
    %   m   = mass of object
    %   C_d = turbulent drag coefficient (see above)

    function derivs = air_drag_1D_derivs(t, w)
    
        global C_d;      % air drag coefficient = 
        global m;        % mass of particle 
        
        g = 9.8;         % acceleration of gravity in m/s^2
        
        x = w(1);        % w(1) stores x
        v = w(2);        % w(2) stores v
        
        dxdt = v;        % set dx/dt = velocity
        dvdt = -g - v * abs(v) * C_d / m ;    % set dv/dt = acceleration
        
        derivs = [dxdt; dvdt];  % return the derivatives
        
    end

